+++
title = "Dealing with underscores"
date = 2017-07-21
tags = ["body"]
draft = false
+++

This underscore should appear escaped in Markdown: \_

This underscore is in a verbatim block, so it should not be escaped:
`_`

This underscore also shouldn't be escaped as it's in an emoji
code: :raised_hands:

And these ones should be eventually removed and <span class="underline">underline</span> the text
(_Requires CSS to do so._) -- **Org syntax**.
